@@ -21,7 +21,7 @@ use Data::Object::Type::Space;
 use Data::Object::Type::String;
 use Data::Object::Type::Undef;
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 Type::Utils::extends('Types::Standard');
 Type::Utils::extends('Types::TypeTiny');
@@ -50,6 +50,7 @@ register Data::Object::Type::Undef;
 # METHODS
 
 1;
+
 =encoding utf8
 
 =head1 NAME
@@ -60,7 +61,7 @@ Data::Object::Library
 
 =head1 ABSTRACT
 
-Data-Object Library Configuration
+Data-Object Type Library
 
 =cut
 
@@ -1104,8 +1105,8 @@ terms as the Perl 5 programming language system itself.
 
 =begin html
 
-<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
-<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+<a href="https://travis-ci.org/iamalnewkirk/do" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/do.svg?branch=master"/>
 </a>
 
 =end html
@@ -1124,8 +1125,8 @@ L<Data::Object::Library>
 
 L<Data::Object::Signatures>
 
-L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+L<Contributing|https://github.com/iamalnewkirk/do/README-DEVEL.mkdn>
 
-L<GitHub|https://github.com/iamalnewkirk/data-object>
+L<GitHub|https://github.com/iamalnewkirk/do>
 
 =cut
\ No newline at end of file
