@@ -7,7 +7,7 @@ use Data::Object::Class;
 
 with 'Data::Object::Role::Immutable';
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 # BUILD
 
@@ -20,6 +20,7 @@ sub BUILD {
 }
 
 1;
+
 =encoding utf8
 
 =head1 NAME
@@ -67,8 +68,8 @@ terms as the Perl 5 programming language system itself.
 
 =begin html
 
-<a href="https://travis-ci.org/iamalnewkirk/data-object" target="_blank">
-<img src="https://travis-ci.org/iamalnewkirk/data-object.svg?branch=master"/>
+<a href="https://travis-ci.org/iamalnewkirk/do" target="_blank">
+<img src="https://travis-ci.org/iamalnewkirk/do.svg?branch=master"/>
 </a>
 
 =end html
@@ -87,8 +88,8 @@ L<Data::Object::Library>
 
 L<Data::Object::Signatures>
 
-L<Contributing|https://github.com/iamalnewkirk/data-object/CONTRIBUTING.mkdn>
+L<Contributing|https://github.com/iamalnewkirk/do/README-DEVEL.mkdn>
 
-L<GitHub|https://github.com/iamalnewkirk/data-object>
+L<GitHub|https://github.com/iamalnewkirk/do>
 
 =cut
\ No newline at end of file
